OiRA

Help

1. Preparação
2. Envolvimento
3. Identificação + Avaliação
4. Plano de Ação
5. Relatório
6. Estado 0%

# Adapte a avaliação de riscos à sua organização

Para adaptar a avaliação de riscos à sua organização poderá ser-lhe pedido para:

- selecionar ou ignorar a(s) situação(ões) relevante(s) ou não à sua atividade empresarial e selecionar a(s) caixa(s) se adequado
- listar unidades empresariais múltiplas, ramos ou departamentos, etc. Estes riscos relacionados serão repetidos para cada nome introduzido.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More